/*
   FNT - SQL-backend for MySQL

   Copyright (C) 2009 Free Software Foundation, Inc.

   Written by:
   Slava Zanko <slavazanko@gmail.com>


   This file is part of the FIDO New Technology.

   FIDO New Technology is free software: you can redistribute it and/or 
   modify it under the terms of the GNU General Public License as published 
   by the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifdef HAVE_CONFIG_H
#	include <config.h>
#endif

#include <stdlib.h>

#include "../include/global.h"

#include "../include/types.h"
#include "../include/error.h"
#include "../include/plugin.h"
#include "../include/sql.h"
#include "main.h"

/*** global variables **************************************************/

fnt_sql_connect_info_t connect_info = {
    NULL,			/* driver */
    false,			/* is_local_path */
    NULL,			/* local_db_path */

    NULL,			/* db_name */
    false,			/* is_persistent */
    NULL,			/* host_name */
    0,				/* port_number */
    NULL,			/* user_name */
    NULL			/* password */
};

/*** file scope macro definitions **************************************/

/*** file scope type declarations **************************************/

/*** file scope variables **********************************************/

/*** file scope functions **********************************************/

/*** public functions **************************************************/

DLLEXPORT fnt_plugin_info_t *
fnt_plugin_get_info (void)
{
    fnt_plugin_info_t *info;

    info = g_try_malloc (sizeof (fnt_plugin_info_t));
    if (info == NULL)
	return NULL;

    info->magic = FNT_PLUGIN_MAGIC;
    info->group = "sql";
    info->name = "mysql";

    return info;
}

DLLEXPORT void
set_local_path_flag (bool is_local_path)
{
    connect_info.is_local_path = is_local_path;
}

DLLEXPORT void
set_local_path (const char *local_db_path)
{
    connect_info.local_db_path = (char *) local_db_path;
}

DLLEXPORT void
set_database (const char *db_name)
{
    connect_info.db_name = (char *) db_name;
}

DLLEXPORT void
set_persistent (bool is_persistent)
{
    connect_info.is_persistent = is_persistent;
}

DLLEXPORT void
set_host (const char *host_name)
{
    connect_info.host_name = (char *) host_name;
}

DLLEXPORT void
set_port (const unsigned int port_number)
{
    connect_info.port_number = (int) port_number;
}

DLLEXPORT void
set_user (const char *user_name)
{
    connect_info.user_name = (char *) user_name;
}

DLLEXPORT void
set_password (const char *password)
{
    connect_info.password = (char *) password;
}

DLLEXPORT bool
init (void)
{
    return true;
}

DLLEXPORT bool
deinit (void)
{
    return true;
}

DLLEXPORT const char *
printBool (bool var)
{
    return (var) ? "1" : "0";
}

DLLEXPORT bool
toBool (const char *var)
{
    if (var == NULL)
	return false;
    return *var == '1' ? true : false;
}
